@@ -2,6 +2,6 @@
 
 __author__ = """Jim Vogel"""
 __email__ = "james.vogel@capspire.com"
-__version__ = "0.1.25"
+__version__ = "0.1.29"
 
-from .tank_forecaster import forecast
+from tank_forecaster.tank_forecaster import forecast_near, forecast_far, clean
